Description: Make the build reproducible
Author: Chris Lamb <lamby@debian.org>
Last-Update: 2018-01-02

Index: klystrack-0.20171212/klystron/Makefile
===================================================================
--- klystrack-0.20171212.orig/klystron/Makefile	2018-03-23 14:05:21.000000000 +0100
+++ klystrack-0.20171212/klystron/Makefile	2018-03-23 14:05:36.000000000 +0100
@@ -28,6 +28,13 @@
 CC = gcc -shared -std=gnu99 --no-strict-aliasing
 CDEP = gcc -E -std=gnu99
 
+DATE_FMT = %Y%m%d
+ifdef SOURCE_DATE_EPOCH
+	KLYSTRON_REVISION ?= $(shell date -u -d "@$(SOURCE_DATE_EPOCH)" "+$(DATE_FMT)"  2>/dev/null || date -u -r "$(SOURCE_DATE_EPOCH)" "+$(DATE_FMT)" 2>/dev/null || date -u "+$(DATE_FMT)")
+else
+	KLYSTRON_REVISION ?= $(shell date "+$(DATE_FMT)")
+endif
+
 ifndef CFLAGS
 CFLAGS = $(MACHINE) -ftree-vectorize
 endif
@@ -73,9 +80,7 @@
 build: Makefile
 	@echo '#ifndef KLYSTRON_VERSION_H' > ./src/version.h
 	@echo '#define KLYSTRON_VERSION_H' >> ./src/version.h
-	@echo -n '#define KLYSTRON_REVISION "' >> ./src/version.h
-	@date +"%Y%m%d" | tr -d '\n' >> ./src/version.h
-	@echo '"' >> ./src/version.h
+	@echo '#define KLYSTRON_REVISION "$(KLYSTRON_REVISION)"' >> ./src/version.h
 	@echo '#define KLYSTRON_VERSION_STRING "klystron " KLYSTRON_REVISION' >> ./src/version.h
 	@echo '#endif' >> ./src/version.h
 	make all CFG=$(CFG)
Index: klystrack-0.20171212/klystrack/Makefile
===================================================================
--- klystrack-0.20171212.orig/klystrack/Makefile	2018-03-23 14:05:21.000000000 +0100
+++ klystrack-0.20171212/klystrack/Makefile	2018-03-23 14:05:36.000000000 +0100
@@ -21,6 +21,13 @@
 
 CFLAGS := $(MACHINE) -ftree-vectorize -std=gnu99 --no-strict-aliasing
 
+DATE_FMT = %Y%m%d
+ifdef SOURCE_DATE_EPOCH
+	REVISION ?= $(shell date -u -d "@$(SOURCE_DATE_EPOCH)" "+$(DATE_FMT)"  2>/dev/null || date -u -r "$(SOURCE_DATE_EPOCH)" "+$(DATE_FMT)" 2>/dev/null || date -u "+$(DATE_FMT)")
+else
+	REVISION ?= $(shell date "+$(DATE_FMT)")
+endif
+
 ifdef COMSPEC
 	TARGET := $(TARGET).exe
 	ARCHIVE := $(ARCHIVE).zip
@@ -133,9 +140,7 @@
 	@echo '#ifndef VERSION_H' > ./src/version.h
 	@echo '#define VERSION_H' >> ./src/version.h
 	@echo '#include "version_number.h"' >> ./src/version.h
-	@echo -n '#define REVISION "' >> ./src/version.h
-	@date +"%Y%m%d" | tr -d '\n' >> ./src/version.h
-	@echo '"' >> ./src/version.h
+	@echo '#define REVISION "$(REVISION)"' >> ./src/version.h
 	@echo '#define VERSION_STRING "klystrack " VERSION " " REVISION' >> ./src/version.h
 	@echo '#endif' >> ./src/version.h
 	
